@@ -1,7 +1,7 @@
-__version__ = '0.0.36'  # print(ultralytics.__version__)
+__version__ = '0.0.38'  # print(ultralytics.__version__)
 
 
-def notebook_init(verbose=True):
+def checks(verbose=True):
     # Checks YOLOv5 software and hardware
     print('Checking setup...')
 
@@ -25,9 +25,8 @@ def notebook_init(verbose=True):
     else:
         s = ''
 
-    select_device(newline=False)
+    select_device(newline=False, version=__version__)
     print(emojis(f'Setup complete ✅ {s}'))
-    return display
 
 
 def login():
